@@ -316,7 +316,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
     env.Default(targets)
 
 
-    env.Command(out, targets + [basename, os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
+    env.Command(out, targets + [os.path.join(basename, ".sconsign.dblite")], "tar cjf $TARGET $SOURCES")
 
     return targets, sources, basename
 
